@@ -1,6 +1,6 @@
 /*
    CheMPS2: a spin-adapted implementation of DMRG for ab initio quantum chemistry
-   Copyright (C) 2013-2018 Sebastian Wouters
+   Copyright (C) 2013-2021 Sebastian Wouters
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -24,9 +24,10 @@
 #include <string>
 #include <climits>
 
+#include <hdf5.h>
+
 #include "FourIndex.h"
 #include "Lapack.h"
-#include "MyHDF5.h"
 #include "MPIchemps2.h"
 
 using namespace std;
